import { RouterView } from 'vue-router';

export default {
    path: '/item',
    name: 'Item',
    meta: {
        title: 'items',
        icon: 'vn:item',
    },
    component: RouterView,
    redirect: { name: 'ItemMain' },
    menus: {
        main: ['ItemList'],
        card: [
            'ItemBasicData',
            'ItemDiary',
            'ItemTags',
            'ItemTax',
            'ItemBotanical',
            'ItemBarcode',
        ],
    },
    children: [
        {
            path: '',
            name: 'ItemMain',
            component: () => import('src/pages/Item/ItemMain.vue'),
            redirect: { name: 'ItemList' },
            children: [
                {
                    path: 'list',
                    name: 'ItemList',
                    meta: {
                        title: 'list',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/Item/ItemList.vue'),
                },
                {
                    path: 'create',
                    name: 'ItemCreate',
                    meta: {
                        title: 'create',
                    },
                    component: () => import('src/pages/Item/ItemCreate.vue'),
                },
            ],
        },
        {
            name: 'ItemCard',
            path: ':id',
            component: () => import('src/pages/Item/Card/ItemCard.vue'),
            redirect: { name: 'ItemSummary' },
            children: [
                {
                    name: 'ItemSummary',
                    path: 'summary',
                    meta: {
                        title: 'summary',
                        icon: 'launch',
                    },
                    component: () => import('src/pages/Item/Card/ItemSummary.vue'),
                },
                {
                    path: 'basic-data',
                    name: 'ItemBasicData',
                    meta: {
                        title: 'basicData',
                        icon: 'vn:settings',
                    },
                    component: () => import('src/pages/Item/Card/ItemBasicData.vue'),
                },

                {
                    path: 'tags',
                    name: 'ItemTags',
                    meta: {
                        title: 'tags',
                        icon: 'vn:tags',
                    },
                    component: () => import('src/pages/Item/Card/ItemTags.vue'),
                },
                {
                    path: 'tax',
                    name: 'ItemTax',
                    meta: {
                        title: 'tax',
                        icon: 'vn:tax',
                    },
                    component: () => import('src/pages/Item/Card/ItemTax.vue'),
                },
                {
                    path: 'botanical',
                    name: 'ItemBotanical',
                    meta: {
                        title: 'botanical',
                        icon: 'vn:botanical',
                    },
                    component: () => import('src/pages/Item/Card/ItemBotanical.vue'),
                },
                {
                    path: 'barcode',
                    name: 'ItemBarcode',
                    meta: {
                        title: 'barcode',
                        icon: 'vn:barcode',
                    },
                    component: () => import('src/pages/Item/Card/ItemBarcode.vue'),
                },
                {
                    path: 'diary',
                    name: 'ItemDiary',
                    meta: {
                        title: 'diary',
                        icon: 'vn:transaction',
                    },
                    component: () => import('src/pages/Item/Card/ItemDiary.vue'),
                },
            ],
        },
    ],
};
